#include <termios.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <errno.h>
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

static FILE *ttyfp = NULL;
static int flow_control_enabled;

static void setup_tty(int port, int baudrate) {
  struct termios tty;

  if(tcgetattr(port, &tty) != 0) {
    printf("tcgetattr error: %s\n", strerror(errno));
    close(port);
    exit(1);
  }
  cfsetispeed(&tty, baudrate);
  cfsetospeed(&tty, baudrate);

  tty.c_cflag &= ~PARENB;
  tty.c_cflag &= ~CSTOPB;
  tty.c_cflag |= CS8;
  tty.c_cflag |= CREAD | CLOCAL;

  tty.c_cflag &= ~CRTSCTS;

  tty.c_lflag &= ~ICANON;
  tty.c_lflag &= ~ECHO;
  tty.c_lflag &= ~ISIG;
  tty.c_lflag &= ~(ECHO | ECHONL | ICANON | ISIG | IEXTEN);

  tty.c_iflag &= ~(IXON | IXOFF | IXANY);
  tty.c_iflag &= ~(IGNBRK|BRKINT|PARMRK|ISTRIP|INLCR|IGNCR|ICRNL);

  tty.c_oflag &= ~OPOST;
  tty.c_oflag &= ~ONLCR;

  if (tcsetattr(port, TCSANOW, &tty) != 0) {
    printf("tcgetattr error: %s\n", strerror(errno));
    exit(1);
  }
}

int main(int argc, char *argv[]) {
  char c;
  int n = 0;
  char *str = "WAIT\n";

  if (argc < 2) {
    printf("Usage: %s [/dev/tty]\n", argv[0]);
    exit(1);
  }

  ttyfp = fopen(argv[1], "r+b");
  if (ttyfp == NULL) {
    printf("Can't open %s\n", argv[1]);
    return -1;
  }

  setup_tty(fileno(ttyfp), B9600);

  printf("Waiting for char\n");
  while (1) {
    c = fgetc(ttyfp);
    if (c == '\n') break;
  }
  printf("replying\n");
  fputc('R', ttyfp);
  fflush(ttyfp);
  // for (n = 0; n < strlen(str); n++) {
  //   fputc(str[n], ttyfp);
  //   fflush(ttyfp);
  //   usleep(3000);
  // }
}
